Module: Teuton
- Defined in:
- lib/teuton.rb
Overview
Main Teuton functions
Class Method Summary collapse
-
.create(path_to_new_dir) ⇒ Object
Create new Teuton project.
-
.play(path_to_rb_file, options = {}) ⇒ Object
Play (run) Teuton project.
-
.readme(path_to_rb_file) ⇒ Object
Generate readme for Teuton project.
-
.test(path_to_rb_file) ⇒ Object
Simulate play Teuton project, check syntax and display stats.
-
.version ⇒ Object
Display Teuton version.
Class Method Details
.create(path_to_new_dir) ⇒ Object
Create new Teuton project
10 11 12 |
# File 'lib/teuton.rb', line 10 def self.create(path_to_new_dir) ProjectCreator.create(path_to_new_dir) end |
.play(path_to_rb_file, options = {}) ⇒ Object
Play (run) Teuton project.
- :export [String]
- :cname [String]
- :cpath [String]
- :case [String]
- :quiet [Boolean]
23 24 25 |
# File 'lib/teuton.rb', line 23 def self.play(path_to_rb_file, = {}) Project.play(path_to_rb_file, ) end |
.readme(path_to_rb_file) ⇒ Object
Generate readme for Teuton project.
30 31 32 |
# File 'lib/teuton.rb', line 30 def self.readme(path_to_rb_file) Project.readme(path_to_rb_file, ) end |
.test(path_to_rb_file) ⇒ Object
Simulate play Teuton project, check syntax and display stats.
37 38 39 |
# File 'lib/teuton.rb', line 37 def self.test(path_to_rb_file) Project.test(path_to_rb_file, ) end |
.version ⇒ Object
Display Teuton version
43 44 45 46 |
# File 'lib/teuton.rb', line 43 def self.version print Rainbow(Application::NAME).bright.blue puts ' (version ' + Rainbow(Application::VERSION).green + ')' end |